==> kdegames-4.3.5-i586-P1.tgz: install/doinst.sh <==
( cd opt/kde/share/doc/HTML/en/lskat ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/lskat ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/ksirkskineditor ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/ksirkskineditor ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kdiamond ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kdiamond ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kmines ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kmines ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/ktron ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/ktron ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/ksirk ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/ksirk ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kgoldrunner ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kgoldrunner ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kapman ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kapman ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/knetwalk ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/knetwalk ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kshisen ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kshisen ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kreversi ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kreversi ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/bovo ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/bovo ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kpat ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kpat ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/ksquares ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/ksquares ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kspaceduel ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kspaceduel ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kfourinline ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kfourinline ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/bomber ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/bomber ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kbounce ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kbounce ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/konquest ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/konquest ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/katomic ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/katomic ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kolf ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kolf ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kubrick ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kubrick ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/ksame ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/ksame ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kbattleship ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kbattleship ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kollision ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kollision ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/ktuberling ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/ktuberling ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kbreakout ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kbreakout ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kmahjongg ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kmahjongg ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/killbots ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/killbots ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kiriki ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kiriki ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kjumpingcube ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kjumpingcube ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kblackbox ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kblackbox ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/klines ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/klines ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/ksudoku ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/ksudoku ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kblocks ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kblocks ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/lib ; rm -rf libkggzmod.so.4 )
( cd opt/kde/lib ; ln -sf libkggzmod.so.4.3.0 libkggzmod.so.4 )
( cd opt/kde/lib ; rm -rf libkdegames.so.5 )
( cd opt/kde/lib ; ln -sf libkdegames.so.5.0.0 libkdegames.so.5 )
( cd opt/kde/lib ; rm -rf libkdegames.so )
( cd opt/kde/lib ; ln -sf libkdegames.so.5 libkdegames.so )
( cd opt/kde/lib ; rm -rf libkggzgames.so.4 )
( cd opt/kde/lib ; ln -sf libkggzgames.so.4.3.0 libkggzgames.so.4 )
( cd opt/kde/lib ; rm -rf libkggznet.so.4 )
( cd opt/kde/lib ; ln -sf libkggznet.so.4.3.0 libkggznet.so.4 )
( cd opt/kde/lib ; rm -rf libkggzgames.so )
( cd opt/kde/lib ; ln -sf libkggzgames.so.4 libkggzgames.so )
( cd opt/kde/lib ; rm -rf libkolfprivate.so )
( cd opt/kde/lib ; ln -sf libkolfprivate.so.4 libkolfprivate.so )
( cd opt/kde/lib ; rm -rf libiris_ksirk.so.2 )
( cd opt/kde/lib ; ln -sf libiris_ksirk.so.2.0.0 libiris_ksirk.so.2 )
( cd opt/kde/lib ; rm -rf libkggznet.so )
( cd opt/kde/lib ; ln -sf libkggznet.so.4 libkggznet.so )
( cd opt/kde/lib ; rm -rf libkggzmod.so )
( cd opt/kde/lib ; ln -sf libkggzmod.so.4 libkggzmod.so )
( cd opt/kde/lib ; rm -rf libkmahjongglib.so.4 )
( cd opt/kde/lib ; ln -sf libkmahjongglib.so.4.3.0 libkmahjongglib.so.4 )
( cd opt/kde/lib ; rm -rf libkmahjongglib.so )
( cd opt/kde/lib ; ln -sf libkmahjongglib.so.4 libkmahjongglib.so )
( cd opt/kde/lib ; rm -rf libkolfprivate.so.4 )
( cd opt/kde/lib ; ln -sf libkolfprivate.so.4.3.0 libkolfprivate.so.4 )
( cd opt/kde/lib ; rm -rf libiris_ksirk.so )
( cd opt/kde/lib ; ln -sf libiris_ksirk.so.2 libiris_ksirk.so )
#%% begin initialize kdegames-4.3.5
if [ -f /opt/kde/bin/plamo_update_kde.sh ]; then
	/bin/bash /opt/kde/bin/plamo_update_kde.sh
fi
#%% end

==> kdegames-4.4.5-i586-P1.tgz: install/doinst.sh <==
( cd opt/kde/lib ; rm -rf libkdegames.so.5 )
( cd opt/kde/lib ; ln -sf libkdegames.so.5.0.0 libkdegames.so.5 )
( cd opt/kde/lib ; rm -rf libkdegames.so )
( cd opt/kde/lib ; ln -sf libkdegames.so.5 libkdegames.so )
( cd opt/kde/lib ; rm -rf libkggznet.so.4 )
( cd opt/kde/lib ; ln -sf libkggznet.so.4.4.0 libkggznet.so.4 )
( cd opt/kde/lib ; rm -rf libkggznet.so )
( cd opt/kde/lib ; ln -sf libkggznet.so.4 libkggznet.so )
( cd opt/kde/lib ; rm -rf libkggzgames.so.4 )
( cd opt/kde/lib ; ln -sf libkggzgames.so.4.4.0 libkggzgames.so.4 )
( cd opt/kde/lib ; rm -rf libkggzgames.so )
( cd opt/kde/lib ; ln -sf libkggzgames.so.4 libkggzgames.so )
( cd opt/kde/lib ; rm -rf libkggzmod.so.4 )
( cd opt/kde/lib ; ln -sf libkggzmod.so.4.4.0 libkggzmod.so.4 )
( cd opt/kde/lib ; rm -rf libkggzmod.so )
( cd opt/kde/lib ; ln -sf libkggzmod.so.4 libkggzmod.so )
( cd opt/kde/lib ; rm -rf libkmahjongglib.so.4 )
( cd opt/kde/lib ; ln -sf libkmahjongglib.so.4.4.0 libkmahjongglib.so.4 )
( cd opt/kde/lib ; rm -rf libkmahjongglib.so )
( cd opt/kde/lib ; ln -sf libkmahjongglib.so.4 libkmahjongglib.so )
( cd opt/kde/lib ; rm -rf libkolfprivate.so.4 )
( cd opt/kde/lib ; ln -sf libkolfprivate.so.4.4.0 libkolfprivate.so.4 )
( cd opt/kde/lib ; rm -rf libkolfprivate.so )
( cd opt/kde/lib ; ln -sf libkolfprivate.so.4 libkolfprivate.so )
( cd opt/kde/lib ; rm -rf libiris_ksirk.so.2 )
( cd opt/kde/lib ; ln -sf libiris_ksirk.so.2.0.0 libiris_ksirk.so.2 )
( cd opt/kde/lib ; rm -rf libiris_ksirk.so )
( cd opt/kde/lib ; ln -sf libiris_ksirk.so.2 libiris_ksirk.so )
( cd opt/kde/lib ; rm -rf libpala.so.0 )
( cd opt/kde/lib ; ln -sf libpala.so.0.1.0 libpala.so.0 )
( cd opt/kde/lib ; rm -rf libpala.so )
( cd opt/kde/lib ; ln -sf libpala.so.0 libpala.so )
( cd opt/kde/share/doc/HTML/en/katomic ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/katomic ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/bovo ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/bovo ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/granatier ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/granatier ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kbattleship ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kbattleship ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kblackbox ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kblackbox ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kblocks ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kblocks ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kbounce ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kbounce ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kbreakout ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kbreakout ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kdiamond ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kdiamond ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kgoldrunner ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kgoldrunner ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/killbots ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/killbots ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kigo ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kigo ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kiriki ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kiriki ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kjumpingcube ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kjumpingcube ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/klines ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/klines ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kmahjongg ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kmahjongg ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kmines ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kmines ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/knetwalk ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/knetwalk ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kolf ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kolf ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kollision ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kollision ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/konquest ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/konquest ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kpat ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kpat ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kreversi ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kreversi ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/ksame ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/ksame ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kshisen ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kshisen ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/ktron ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/ktron ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/ksirk ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/ksirk ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/ksirkskineditor ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/ksirkskineditor ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kspaceduel ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kspaceduel ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/ksquares ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/ksquares ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/ktuberling ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/ktuberling ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kfourinline ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kfourinline ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/lskat ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/lskat ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kapman ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kapman ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/bomber ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/bomber ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/palapeli ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/palapeli ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/ksudoku ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/ksudoku ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kubrick ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kubrick ; ln -sf /opt/kde/share/doc/HTML/en/common common )
#%% begin initialize kdegames-4.4.5
if [ -f /opt/kde/bin/plamo_update_kde.sh ]; then
	/bin/bash /opt/kde/bin/plamo_update_kde.sh
fi
#%% end
